summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrian Cameron <bcameron@src.gnome.org>2007-11-30 18:27:11 +0000
committerBrian Cameron <bcameron@src.gnome.org>2007-11-30 18:27:11 +0000
commit7a1edc39c7c822578025b06ba4e3cf8fd5e47f55 (patch)
tree51e80b5f2f96786afd5d1c32430fbe7e7a8e644a
parent199ccb69140e90cacc00da309b1abb94aadd5f36 (diff)
downloadgdm-7a1edc39c7c822578025b06ba4e3cf8fd5e47f55.tar.gz
Brian Cameron <brian.cameron@sun.com>
Thanks to George Lebl for noticing these issues. * daemon/errorgui.c, daemon/gdmconsolekit.c, daemon/display.c, daemon/gdm.c, daemon/filecheck.c, daemon/verify-shadow.c, daemon/gdm-xdmcp-manager.c, daemon/verify-crypt.c, daemon/server.c, daemon/slave.c, daemon/gdm-daemon-config.c, daemon/choose.c, daemon/misc.c: Use gdm_debug instead of g_warning and g_debug. * daemon/gdm-xdmcp-manager.c: Fix bug where WILLING script was being read from the configuration file as an int rather than a string. svn path=/branches/gnome-2-20/; revision=5533
-rw-r--r--ChangeLog12
-rw-r--r--daemon/choose.c2
-rw-r--r--daemon/display.c2
-rw-r--r--daemon/errorgui.c8
-rw-r--r--daemon/filecheck.c31
-rw-r--r--daemon/gdm-daemon-config.c8
-rw-r--r--daemon/gdm-xdmcp-manager.c229
-rw-r--r--daemon/gdm.c98
-rw-r--r--daemon/gdmconsolekit.c2
-rw-r--r--daemon/misc.c2
-rw-r--r--daemon/server.c4
-rw-r--r--daemon/slave.c16
-rw-r--r--daemon/verify-crypt.c22
-rw-r--r--daemon/verify-shadow.c22
14 files changed, 235 insertions, 223 deletions
diff --git a/ChangeLog b/ChangeLog
index bc1c55f9..1f3af3c3 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,17 @@
2007-11-30 Brian Cameron <brian.cameron@sun.com>
+ Thanks to George Lebl for noticing these issues.
+ * daemon/errorgui.c, daemon/gdmconsolekit.c, daemon/display.c,
+ daemon/gdm.c, daemon/filecheck.c, daemon/verify-shadow.c,
+ daemon/gdm-xdmcp-manager.c, daemon/verify-crypt.c, daemon/server.c,
+ daemon/slave.c, daemon/gdm-daemon-config.c, daemon/choose.c,
+ daemon/misc.c: Use gdm_debug instead of g_warning and g_debug.
+ * daemon/gdm-xdmcp-manager.c: Fix bug where WILLING script was
+ being read from the configuration file as an int rather than a
+ string.
+
+2007-11-30 Brian Cameron <brian.cameron@sun.com>
+
* daemon/gdm.c, daemon/slave.c: Fix Suspend configuration option
so it works. Fixes bug #500362. Patch by Philippe Troin
<phil@fifi.org>.
diff --git a/daemon/choose.c b/daemon/choose.c
index bd08b10c..3aad9c1b 100644
--- a/daemon/choose.c
+++ b/daemon/choose.c
@@ -104,7 +104,7 @@ get_first_address_for_node (const char *node,
snprintf (strport, sizeof (strport), "%u", XDM_UDP_PORT);
if ((gaierr = getaddrinfo (node, strport, &hints, &ai_list)) != 0) {
- g_warning ("Unable get address: %s", gai_strerror (gaierr));
+ gdm_debug ("Unable get address: %s", gai_strerror (gaierr));
return FALSE;
}
diff --git a/daemon/display.c b/daemon/display.c
index 7a9db56b..b475ad79 100644
--- a/daemon/display.c
+++ b/daemon/display.c
@@ -357,7 +357,7 @@ gdm_display_manage (GdmDisplay *d)
d->managetime = time (NULL);
- g_debug ("Forking slave process");
+ gdm_debug ("Forking slave process");
/* Fork slave process */
pid = d->slavepid = fork ();
diff --git a/daemon/errorgui.c b/daemon/errorgui.c
index 082c7770..302cdf17 100644
--- a/daemon/errorgui.c
+++ b/daemon/errorgui.c
@@ -310,7 +310,7 @@ gdm_errorgui_error_box_full (GdmDisplay *d,
GdkDisplay *gdk_display;
pid_t pid;
- g_debug ("Forking extra process: error dialog");
+ gdm_debug ("Forking extra process: error dialog");
pid = gdm_fork_extra ();
@@ -534,7 +534,7 @@ gdm_errorgui_failsafe_question (GdmDisplay *d,
if G_UNLIKELY (pipe (p) < 0)
return NULL;
- g_debug ("Forking extra process: failsafe question");
+ gdm_debug ("Forking extra process: failsafe question");
pid = gdm_fork_extra ();
if (pid == 0) {
@@ -664,7 +664,7 @@ gdm_errorgui_failsafe_yesno (GdmDisplay *d,
if G_UNLIKELY (pipe (p) < 0)
return FALSE;
- g_debug ("Forking extra process: failsafe yes/no");
+ gdm_debug ("Forking extra process: failsafe yes/no");
pid = gdm_fork_extra ();
if (pid == 0) {
@@ -778,7 +778,7 @@ gdm_errorgui_failsafe_ask_buttons (GdmDisplay *d,
if G_UNLIKELY (pipe (p) < 0)
return -1;
- g_debug ("Forking extra process: failsafe ask buttons");
+ gdm_debug ("Forking extra process: failsafe ask buttons");
pid = gdm_fork_extra ();
if (pid == 0) {
diff --git a/daemon/filecheck.c b/daemon/filecheck.c
index 10839d16..c63efe4b 100644
--- a/daemon/filecheck.c
+++ b/daemon/filecheck.c
@@ -26,6 +26,7 @@
#include "gdm.h"
#include "gdm-common.h"
#include "gdm-daemon-config.h"
+#include "gdm-log.h"
#include "filecheck.h"
@@ -78,7 +79,7 @@ gdm_file_check (const gchar *caller,
if (r < 0) {
if ( ! absentdirok)
- g_warning ("%s: Directory %s does not exist.",
+ gdm_debug ("%s: Directory %s does not exist.",
caller, dir);
return FALSE;
}
@@ -90,19 +91,19 @@ gdm_file_check (const gchar *caller,
2004-06-22, Andreas Schubert, MATHEMA Software GmbH */
if G_UNLIKELY (gdm_daemon_config_get_value_bool (GDM_KEY_CHECK_DIR_OWNER) && (statbuf.st_uid != user)) {
- g_warning ("%s: %s is not owned by uid %d.", caller, dir, user);
+ gdm_debug ("%s: %s is not owned by uid %d.", caller, dir, user);
return FALSE;
}
/* ... if group has write permission ... */
if G_UNLIKELY (perms < 1 && (statbuf.st_mode & S_IWGRP) == S_IWGRP) {
- g_warning ("%s: %s is writable by group.", caller, dir);
+ gdm_debug ("%s: %s is writable by group.", caller, dir);
return FALSE;
}
/* ... and if others have write permission. */
if G_UNLIKELY (perms < 2 && (statbuf.st_mode & S_IWOTH) == S_IWOTH) {
- g_warning ("%s: %s is writable by other.", caller, dir);
+ gdm_debug ("%s: %s is writable by other.", caller, dir);
return FALSE;
}
@@ -117,7 +118,7 @@ gdm_file_check (const gchar *caller,
return TRUE;
}
else {
- g_warning ("%s: %s does not exist but must exist.", caller, fullpath);
+ gdm_debug ("%s: %s does not exist but must exist.", caller, fullpath);
g_free (fullpath);
return FALSE;
}
@@ -125,35 +126,35 @@ gdm_file_check (const gchar *caller,
/* Check that it is a regular file ... */
if G_UNLIKELY (! S_ISREG (statbuf.st_mode)) {
- g_warning ("%s: %s is not a regular file.", caller, fullpath);
+ gdm_debug ("%s: %s is not a regular file.", caller, fullpath);
g_free (fullpath);
return FALSE;
}
/* ... owned by the user ... */
if G_UNLIKELY (statbuf.st_uid != user) {
- g_warning ("%s: %s is not owned by uid %d.", caller, fullpath, user);
+ gdm_debug ("%s: %s is not owned by uid %d.", caller, fullpath, user);
g_free (fullpath);
return FALSE;
}
/* ... unwritable by group ... */
if G_UNLIKELY (perms < 1 && (statbuf.st_mode & S_IWGRP) == S_IWGRP) {
- g_warning ("%s: %s is writable by group.", caller, fullpath);
+ gdm_debug ("%s: %s is writable by group.", caller, fullpath);
g_free (fullpath);
return FALSE;
}
/* ... unwritable by others ... */
if G_UNLIKELY (perms < 2 && (statbuf.st_mode & S_IWOTH) == S_IWOTH) {
- g_warning ("%s: %s is writable by group/other.", caller, fullpath);
+ gdm_debug ("%s: %s is writable by group/other.", caller, fullpath);
g_free (fullpath);
return FALSE;
}
/* ... and smaller than sysadmin specified limit. */
if G_UNLIKELY (maxsize && statbuf.st_size > maxsize) {
- g_warning ("%s: %s is bigger than sysadmin specified maximum file size.",
+ gdm_debug ("%s: %s is bigger than sysadmin specified maximum file size.",
caller, fullpath);
g_free (fullpath);
return FALSE;
@@ -187,32 +188,32 @@ gdm_auth_file_check (const gchar *caller,
if (r < 0) {
if (absentok)
return TRUE;
- g_warning ("%s: %s does not exist but must exist.", caller, authfile);
+ gdm_debug ("%s: %s does not exist but must exist.", caller, authfile);
return FALSE;
}
/* Check that it is a regular file ... */
if G_UNLIKELY (! S_ISREG (statbuf.st_mode)) {
- g_warning ("%s: %s is not a regular file.", caller, authfile);
+ gdm_debug ("%s: %s is not a regular file.", caller, authfile);
return FALSE;
}
/* ... owned by the user ... */
if G_UNLIKELY (statbuf.st_uid != user) {
- g_warning ("%s: %s is not owned by uid %d.", caller, authfile, user);
+ gdm_debug ("%s: %s is not owned by uid %d.", caller, authfile, user);
return FALSE;
}
/* ... has right permissions ... */
if G_UNLIKELY (statbuf.st_mode & 0077) {
- g_warning ("%s: %s has wrong permissions (should be 0600)", caller, authfile);
+ gdm_debug ("%s: %s has wrong permissions (should be 0600)", caller, authfile);
return FALSE;
}
usermaxfile = gdm_daemon_config_get_value_int (GDM_KEY_USER_MAX_FILE);
/* ... and smaller than sysadmin specified limit. */
if G_UNLIKELY (usermaxfile && statbuf.st_size > usermaxfile) {
- g_warning ("%s: %s is bigger than sysadmin specified maximum file size.",
+ gdm_debug ("%s: %s is bigger than sysadmin specified maximum file size.",
caller, authfile);
return FALSE;
}
diff --git a/daemon/gdm-daemon-config.c b/daemon/gdm-daemon-config.c
index 5111d8d0..0bdd5307 100644
--- a/daemon/gdm-daemon-config.c
+++ b/daemon/gdm-daemon-config.c
@@ -537,7 +537,7 @@ gdm_daemon_config_key_to_string_per_display (const char *keystring,
goto out;
}
- g_debug ("Looking up per display value for %s", keystring);
+ gdm_debug ("Looking up per display value for %s", keystring);
res = gdm_common_config_parse_key_string (keystring,
&group,
@@ -602,7 +602,7 @@ gdm_daemon_config_key_to_string (const char *file,
&key,
&locale,
NULL);
- g_debug ("Requesting group=%s key=%s locale=%s", group, key, locale ? locale : "(null)");
+ gdm_debug ("Requesting group=%s key=%s locale=%s", group, key, locale ? locale : "(null)");
if (! res) {
gdm_error ("Could not parse configuration key %s", keystring);
@@ -712,7 +712,7 @@ gdm_daemon_config_to_string (const char *keystring,
if (display != NULL) {
res = gdm_daemon_config_key_to_string_per_display (keystring, display, retval);
if (res) {
- g_debug ("Using per display value for key: %s", keystring);
+ gdm_debug ("Using per display value for key: %s", keystring);
return TRUE;
}
}
@@ -720,7 +720,7 @@ gdm_daemon_config_to_string (const char *keystring,
ret = FALSE;
result = NULL;
- g_debug ("Looking up key: %s", keystring);
+ gdm_debug ("Looking up key: %s", keystring);
group = NULL;
key = NULL;
diff --git a/daemon/gdm-xdmcp-manager.c b/daemon/gdm-xdmcp-manager.c
index 98f00050..f8355756 100644
--- a/daemon/gdm-xdmcp-manager.c
+++ b/daemon/gdm-xdmcp-manager.c
@@ -58,6 +58,7 @@
#include "cookie.h"
#include "choose.h"
#include "gdm-daemon-config.h"
+#include "gdm-log.h"
/*
* On Sun, we need to define allow_severity and deny_severity to link
@@ -385,11 +386,11 @@ debug_addrinfo (struct addrinfo *ai)
{
char *str;
str = ai_flags_str (ai);
- g_debug ("XDMCP: addrinfo family=%s type=%s proto=%s flags=%s",
- ai_family_str (ai),
- ai_type_str (ai),
- ai_protocol_str (ai),
- str);
+ gdm_debug ("XDMCP: addrinfo family=%s type=%s proto=%s flags=%s",
+ ai_family_str (ai),
+ ai_type_str (ai),
+ ai_protocol_str (ai),
+ str);
g_free (str);
}
@@ -400,12 +401,12 @@ create_socket (struct addrinfo *ai)
sock = socket (ai->ai_family, ai->ai_socktype, ai->ai_protocol);
if (sock < 0) {
- g_warning ("socket: %s", g_strerror (errno));
+ gdm_debug ("socket: %s", g_strerror (errno));
return sock;
}
if (bind (sock, ai->ai_addr, ai->ai_addrlen) < 0) {
- g_warning ("bind: %s", g_strerror (errno));
+ gdm_debug ("bind: %s", g_strerror (errno));
close (sock);
return -1;
}
@@ -451,7 +452,7 @@ do_bind (guint port,
char *serv;
gdm_address_get_info ((struct sockaddr_storage *)ai->ai_addr, &host, &serv);
- g_debug ("XDMCP: Attempting to bind to host %s port %s", host, serv);
+ gdm_debug ("XDMCP: Attempting to bind to host %s port %s", host, serv);
g_free (host);
g_free (serv);
sock = create_socket (ai);
@@ -514,8 +515,8 @@ setup_multicast (GdmXdmcpManager *manager)
ifreq.ifr_name[sizeof (ifreq.ifr_name) - 1] = '\0';
if (ioctl (socktemp, SIOCGIFFLAGS, &ifreq) < 0) {
- g_debug ("XDMCP: Could not get SIOCGIFFLAGS for %s",
- ifr[i].ifr_name);
+ gdm_debug ("XDMCP: Could not get SIOCGIFFLAGS for %s",
+ ifr[i].ifr_name);
}
ifindex = if_nametoindex (ifr[i].ifr_name);
@@ -550,8 +551,8 @@ open_port (GdmXdmcpManager *manager)
{
struct sockaddr_storage serv_sa = { 0 };
- g_debug ("XDMCP: Start up on host %s, port %d",
- manager->priv->hostname,
+ gdm_debug ("XDMCP: Start up on host %s, port %d",
+ manager->priv->hostname,
manager->priv->port);
/* Open socket for communications */
@@ -562,7 +563,7 @@ open_port (GdmXdmcpManager *manager)
manager->priv->socket_fd = do_bind (manager->priv->port, AF_INET, &serv_sa);
if G_UNLIKELY (manager->priv->socket_fd < 0) {
- g_warning ("Could not create socket!");
+ gdm_debug ("Could not create socket!");
return FALSE;
}
@@ -598,8 +599,8 @@ gdm_xdmcp_host_allow (struct sockaddr_storage *clnt_sa)
if (client_he->not_found) {
client = "unknown";
} else {
- g_debug ("gdm_xdmcp_host_allow: client->hostname is %s\n",
- client_he->hostname);
+ gdm_debug ("gdm_xdmcp_host_allow: client->hostname is %s\n",
+ client_he->hostname);
client = client_he->hostname;
}
@@ -717,7 +718,7 @@ gdm_xdmcp_send_willing (GdmXdmcpManager *manager,
char *host;
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("XDMCP: Sending WILLING to %s", host);
+ gdm_debug ("XDMCP: Sending WILLING to %s", host);
g_free (host);
if (last_willing == 0 || time (NULL) - 3 > last_willing) {
@@ -784,8 +785,8 @@ gdm_xdmcp_send_unwilling (GdmXdmcpManager *manager,
}
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("XDMCP: Sending UNWILLING to %s", host);
- g_warning ("Denied XDMCP query from host %s", host);
+ gdm_debug ("XDMCP: Sending UNWILLING to %s", host);
+ gdm_debug ("Denied XDMCP query from host %s", host);
g_free (host);
/*
@@ -874,13 +875,13 @@ gdm_xdmcp_send_forward_query (GdmXdmcpManager *manager,
g_assert (id->chosen_host != NULL);
gdm_address_get_info (id->chosen_host, &host, NULL);
- g_debug ("XDMCP: Sending forward query to %s",
- host);
+ gdm_debug ("XDMCP: Sending forward query to %s",
+ host);
g_free (host);
gdm_address_get_info (display_addr, &host, &serv);
- g_debug ("gdm_xdmcp_send_forward_query: Query contains %s:%s",
- host, serv);
+ gdm_debug ("gdm_xdmcp_send_forward_query: Query contains %s:%s",
+ host, serv);
g_free (host);
g_free (serv);
@@ -936,7 +937,7 @@ handle_direct_query (GdmXdmcpManager *manager,
res = XdmcpReadARRAYofARRAY8 (&manager->priv->buf, &clnt_authlist);
if G_UNLIKELY (! res) {
- g_warning ("Could not extract authlist from packet");
+ gdm_debug ("Could not extract authlist from packet");
return;
}
@@ -949,7 +950,7 @@ handle_direct_query (GdmXdmcpManager *manager,
if (len == expected_len) {
handle_any_query (manager, clnt_sa, &clnt_authlist, type);
} else {
- g_warning ("Error in checksum");
+ gdm_debug ("Error in checksum");
}
XdmcpDisposeARRAYofARRAY8 (&clnt_authlist);
@@ -1001,7 +1002,7 @@ gdm_xdmcp_handle_indirect_query (GdmXdmcpManager *manager,
res = XdmcpReadARRAYofARRAY8 (&manager->priv->buf, &clnt_authlist);
if G_UNLIKELY (! res) {
- g_warning ("Could not extract authlist from packet");
+ gdm_debug ("Could not extract authlist from packet");
return;
}
@@ -1065,7 +1066,7 @@ gdm_xdmcp_handle_indirect_query (GdmXdmcpManager *manager,
}
} else {
- g_warning ("Error in checksum");
+ gdm_debug ("Error in checksum");
}
XdmcpDisposeARRAYofARRAY8 (&clnt_authlist);
@@ -1087,7 +1088,7 @@ gdm_forward_query_dispose (GdmXdmcpManager *manager,
char *host;
gdm_address_get_info (q->dsp_sa, &host, NULL);
- g_debug ("gdm_forward_query_dispose: Disposing %s", host);
+ gdm_debug ("gdm_forward_query_dispose: Disposing %s", host);
g_free (host);
}
@@ -1174,8 +1175,8 @@ gdm_forward_query_lookup (GdmXdmcpManager *manager,
gdm_address_get_info (q->dsp_sa, &host, &serv);
- g_debug ("gdm_forward_query_lookup: Disposing stale forward query from %s:%s",
- host, serv);
+ gdm_debug ("gdm_forward_query_lookup: Disposing stale forward query from %s:%s",
+ host, serv);
g_free (host);
g_free (serv);
@@ -1190,8 +1191,8 @@ gdm_forward_query_lookup (GdmXdmcpManager *manager,
char *host;
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("gdm_forward_query_lookup: Host %s not found",
- host);
+ gdm_debug ("gdm_forward_query_lookup: Host %s not found",
+ host);
g_free (host);
}
@@ -1253,7 +1254,7 @@ create_sa_from_request (ARRAY8 *req_addr,
}
if (host == NULL) {
- g_warning ("Bad address");
+ gdm_debug ("Bad address");
return FALSE;
}
@@ -1261,7 +1262,7 @@ create_sa_from_request (ARRAY8 *req_addr,
hints.ai_family = family;
hints.ai_flags = AI_V4MAPPED; /* this should convert IPv4 address to IPv6 if needed */
if ((gaierr = getaddrinfo (host, serv, &hints, &ai_list)) != 0) {
- g_warning ("Unable get address: %s", gai_strerror (gaierr));
+ gdm_debug ("Unable get address: %s", gai_strerror (gaierr));
return FALSE;
}
@@ -1324,7 +1325,7 @@ gdm_xdmcp_handle_forward_query (GdmXdmcpManager *manager,
gdm_address_get_info (clnt_sa, &host, NULL);
- g_warning ("%s: Got FORWARD_QUERY from banned host %s",
+ gdm_debug ("%s: Got FORWARD_QUERY from banned host %s",
"gdm_xdmcp_handle_forward query",
host);
g_free (host);
@@ -1333,7 +1334,7 @@ gdm_xdmcp_handle_forward_query (GdmXdmcpManager *manager,
/* Read display address */
if G_UNLIKELY (! XdmcpReadARRAY8 (&manager->priv->buf, &clnt_addr)) {
- g_warning ("%s: Could not read display address",
+ gdm_debug ("%s: Could not read display address",
"gdm_xdmcp_handle_forward_query");
return;
}
@@ -1341,7 +1342,7 @@ gdm_xdmcp_handle_forward_query (GdmXdmcpManager *manager,
/* Read display port */
if G_UNLIKELY (! XdmcpReadARRAY8 (&manager->priv->buf, &clnt_port)) {
XdmcpDisposeARRAY8 (&clnt_addr);
- g_warning ("%s: Could not read display port number",
+ gdm_debug ("%s: Could not read display port number",
"gdm_xdmcp_handle_forward_query");
return;
}
@@ -1350,7 +1351,7 @@ gdm_xdmcp_handle_forward_query (GdmXdmcpManager *manager,
if G_UNLIKELY (! XdmcpReadARRAYofARRAY8 (&manager->priv->buf, &clnt_authlist)) {
XdmcpDisposeARRAY8 (&clnt_addr);
XdmcpDisposeARRAY8 (&clnt_port);
- g_warning ("%s: Could not extract authlist from packet",
+ gdm_debug ("%s: Could not extract authlist from packet",
"gdm_xdmcp_handle_forward_query");
return;
}
@@ -1363,20 +1364,20 @@ gdm_xdmcp_handle_forward_query (GdmXdmcpManager *manager,
for (i = 0 ; i < clnt_authlist.length ; i++) {
char *s = g_strndup ((char *) clnt_authlist.data[i].data,
clnt_authlist.length);
- g_debug ("gdm_xdmcp_handle_forward_query: authlist: %s", s);
+ gdm_debug ("gdm_xdmcp_handle_forward_query: authlist: %s", s);
g_free (s);
explen += 2 + clnt_authlist.data[i].length;
}
if G_UNLIKELY (len != explen) {
- g_warning ("%s: Error in checksum",
+ gdm_debug ("%s: Error in checksum",
"gdm_xdmcp_handle_forward_query");
goto out;
}
if (! create_sa_from_request (&clnt_addr, &clnt_port, clnt_sa->ss_family, &disp_sa)) {
- g_warning ("Unable to parse address for request");
+ gdm_debug ("Unable to parse address for request");
goto out;
}
@@ -1385,8 +1386,8 @@ gdm_xdmcp_handle_forward_query (GdmXdmcpManager *manager,
disp_sa);
gdm_address_get_info (disp_sa, &host, &serv);
- g_debug ("gdm_xdmcp_handle_forward_query: Got FORWARD_QUERY for display: %s, port %s",
- host, serv);
+ gdm_debug ("gdm_xdmcp_handle_forward_query: Got FORWARD_QUERY for display: %s, port %s",
+ host, serv);
g_free (host);
g_free (serv);
@@ -1421,7 +1422,7 @@ gdm_xdmcp_really_send_managed_forward (GdmXdmcpManager *manager,
char *host;
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("XDMCP: Sending MANAGED_FORWARD to %s", host);
+ gdm_debug ("XDMCP: Sending MANAGED_FORWARD to %s", host);
g_free (host);
set_address_for_request (origin, &address);
@@ -1493,7 +1494,7 @@ gdm_xdmcp_send_got_managed_forward (GdmXdmcpManager *manager,
char *host;
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("XDMCP: Sending GOT_MANAGED_FORWARD to %s", host);
+ gdm_debug ("XDMCP: Sending GOT_MANAGED_FORWARD to %s", host);
g_free (host);
set_address_for_request (origin, &address);
@@ -1550,8 +1551,8 @@ gdm_xdmcp_displays_purge (GdmXdmcpManager *manager)
SERVER_IS_XDMCP (d) &&
d->dispstat == XDMCP_PENDING &&
curtime > d->acctime + manager->priv->max_wait) {
- g_debug ("gdm_xdmcp_displays_purge: Disposing session id %ld",
- (long)d->sessionid);
+ gdm_debug ("gdm_xdmcp_displays_purge: Disposing session id %ld",
+ (long)d->sessionid);
gdm_display_dispose (d);
sess_dirty = TRUE;
@@ -1582,7 +1583,7 @@ gdm_xdmcp_display_dispose_check (GdmXdmcpManager *manager,
return;
}
- g_debug ("gdm_xdmcp_display_dispose_check (%s:%d)", hostname, dspnum);
+ gdm_debug ("gdm_xdmcp_display_dispose_check (%s:%d)", hostname, dspnum);
displays = gdm_daemon_config_get_display_list ();
@@ -1629,7 +1630,7 @@ gdm_xdmcp_send_decline (GdmXdmcpManager *manager,
char *host;
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("XDMCP: Sending DECLINE to %s", host);
+ gdm_debug ("XDMCP: Sending DECLINE to %s", host);
g_free (host);
authentype.data = (CARD8 *) 0;
@@ -1687,7 +1688,7 @@ gdm_xdmcp_display_alloc (GdmXdmcpManager *manager,
if (use_proxy && proxycmd != NULL) {
d->type = TYPE_XDMCP_PROXY;
d->command = g_strdup (proxycmd);
- g_debug ("Using proxy server for XDMCP: %s\n", d->command);
+ gdm_debug ("Using proxy server for XDMCP: %s\n", d->command);
} else {
d->type = TYPE_XDMCP;
}
@@ -1752,7 +1753,7 @@ gdm_xdmcp_display_alloc (GdmXdmcpManager *manager,
/* Secure display with cookie */
if G_UNLIKELY (! gdm_auth_secure_display (d)) {
- g_warning ("gdm_xdmcp_display_alloc: Error setting up cookies for %s",
+ gdm_debug ("gdm_xdmcp_display_alloc: Error setting up cookies for %s",
d->name);
}
@@ -1769,7 +1770,7 @@ gdm_xdmcp_display_alloc (GdmXdmcpManager *manager,
manager->priv->num_pending_sessions++;
- g_debug ("gdm_xdmcp_display_alloc: display=%s, session id=%ld, xdmcp_pending=%d",
+ gdm_debug ("gdm_xdmcp_display_alloc: display=%s, session id=%ld, xdmcp_pending=%d",
d->name, (long)d->sessionid, manager->priv->num_pending_sessions);
return d;
@@ -1808,9 +1809,9 @@ gdm_xdmcp_send_accept (GdmXdmcpManager *manager,
(int)gdm_sockaddr_len(clnt_sa));
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("XDMCP: Sending ACCEPT to %s with SessionID=%ld",
- host,
- (long)session_id);
+ gdm_debug ("XDMCP: Sending ACCEPT to %s with SessionID=%ld",
+ host,
+ (long)session_id);
g_free (host);
}
@@ -1836,11 +1837,11 @@ gdm_xdmcp_handle_request (GdmXdmcpManager *manager,
entered = FALSE;
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("gdm_xdmcp_handle_request: Got REQUEST from %s", host);
+ gdm_debug ("gdm_xdmcp_handle_request: Got REQUEST from %s", host);
/* Check with tcp_wrappers if client is allowed to access */
if (! gdm_xdmcp_host_allow (clnt_sa)) {
- g_warning ("%s: Got REQUEST from banned host %s",
+ gdm_debug ("%s: Got REQUEST from banned host %s",
"gdm_xdmcp_handle_request",
host);
g_free (host);
@@ -1858,21 +1859,21 @@ gdm_xdmcp_handle_request (GdmXdmcpManager *manager,
/* Remote display number */
if G_UNLIKELY (! XdmcpReadCARD16 (&manager->priv->buf, &clnt_dspnum)) {
- g_warning ("%s: Could not read Display Number",
+ gdm_debug ("%s: Could not read Display Number",
"gdm_xdmcp_handle_request");
return;
}
/* We don't care about connection type. Address says it all */
if G_UNLIKELY (! XdmcpReadARRAY16 (&manager->priv->buf, &clnt_conntyp)) {
- g_warning ("%s: Could not read Connection Type",
+ gdm_debug ("%s: Could not read Connection Type",
"gdm_xdmcp_handle_request");
return;
}
/* This is TCP/IP - we don't care */
if G_UNLIKELY (! XdmcpReadARRAYofARRAY8 (&manager->priv->buf, &clnt_addr)) {
- g_warning ("%s: Could not read Client Address",
+ gdm_debug ("%s: Could not read Client Address",
"gdm_xdmcp_handle_request");
XdmcpDisposeARRAY16 (&clnt_conntyp);
return;
@@ -1880,7 +1881,7 @@ gdm_xdmcp_handle_request (GdmXdmcpManager *manager,
/* Read authentication type */
if G_UNLIKELY (! XdmcpReadARRAY8 (&manager->priv->buf, &clnt_authname)) {
- g_warning ("%s: Could not read Authentication Names",
+ gdm_debug ("%s: Could not read Authentication Names",
"gdm_xdmcp_handle_request");
XdmcpDisposeARRAYofARRAY8 (&clnt_addr);
XdmcpDisposeARRAY16 (&clnt_conntyp);
@@ -1889,7 +1890,7 @@ gdm_xdmcp_handle_request (GdmXdmcpManager *manager,
/* Read authentication data */
if G_UNLIKELY (! XdmcpReadARRAY8 (&manager->priv->buf, &clnt_authdata)) {
- g_warning ("%s: Could not read Authentication Data",
+ gdm_debug ("%s: Could not read Authentication Data",
"gdm_xdmcp_handle_request");
XdmcpDisposeARRAYofARRAY8 (&clnt_addr);
XdmcpDisposeARRAY16 (&clnt_conntyp);
@@ -1899,7 +1900,7 @@ gdm_xdmcp_handle_request (GdmXdmcpManager *manager,
/* Read and select from supported authorization list */
if G_UNLIKELY (! XdmcpReadARRAYofARRAY8 (&manager->priv->buf, &clnt_authorization)) {
- g_warning ("%s: Could not read Authorization List",
+ gdm_debug ("%s: Could not read Authorization List",
"gdm_xdmcp_handle_request");
XdmcpDisposeARRAY8 (&clnt_authdata);
XdmcpDisposeARRAYofARRAY8 (&clnt_addr);
@@ -1917,7 +1918,7 @@ gdm_xdmcp_handle_request (GdmXdmcpManager *manager,
/* Manufacturer ID */
if G_UNLIKELY (! XdmcpReadARRAY8 (&manager->priv->buf, &clnt_manufacturer)) {
- g_warning ("%s: Could not read Manufacturer ID",
+ gdm_debug ("%s: Could not read Manufacturer ID",
"gdm_xdmcp_handle_request");
XdmcpDisposeARRAY8 (&clnt_authname);
XdmcpDisposeARRAY8 (&clnt_authdata);
@@ -1942,7 +1943,7 @@ gdm_xdmcp_handle_request (GdmXdmcpManager *manager,
if G_UNLIKELY (explen != len) {
gdm_address_get_info (clnt_sa, &host, NULL);
- g_warning ("%s: Failed checksum from %s",
+ gdm_debug ("%s: Failed checksum from %s",
"gdm_xdmcp_handle_request",
host);
g_free (host);
@@ -1958,12 +1959,12 @@ gdm_xdmcp_handle_request (GdmXdmcpManager *manager,
{
char *s = g_strndup ((char *) clnt_manufacturer.data, clnt_manufacturer.length);
- g_debug ("gdm_xdmcp_handle_request: xdmcp_pending=%d, MaxPending=%d, xdmcp_sessions=%d, MaxSessions=%d, ManufacturerID=%s",
- manager->priv->num_pending_sessions,
- manager->priv->max_pending_displays,
- manager->priv->num_sessions,
- manager->priv->max_displays,
- ve_sure_string (s));
+ gdm_debug ("gdm_xdmcp_handle_request: xdmcp_pending=%d, MaxPending=%d, xdmcp_sessions=%d, MaxSessions=%d, ManufacturerID=%s",
+ manager->priv->num_pending_sessions,
+ manager->priv->max_pending_displays,
+ manager->priv->num_sessions,
+ manager->priv->max_displays,
+ ve_sure_string (s));
g_free (s);
}
@@ -1983,7 +1984,7 @@ gdm_xdmcp_handle_request (GdmXdmcpManager *manager,
gdm_xdmcp_display_dispose_check (manager, he->hostname, clnt_dspnum);
if (manager->priv->num_pending_sessions >= manager->priv->max_pending_displays) {
- g_debug ("gdm_xdmcp_handle_request: maximum pending");
+ gdm_debug ("gdm_xdmcp_handle_request: maximum pending");
/* Don't translate, this goes over the wire to servers where we
* don't know the charset or language, so it must be ascii */
gdm_xdmcp_send_decline (manager, clnt_sa, "Maximum pending servers");
@@ -2030,13 +2031,13 @@ gdm_xdmcp_handle_request (GdmXdmcpManager *manager,
clnt_sa,
"Only MIT-MAGIC-COOKIE-1 supported");
} else if (manager->priv->num_sessions >= manager->priv->max_displays) {
- g_warning ("Maximum number of open XDMCP sessions reached");
+ gdm_debug ("Maximum number of open XDMCP sessions reached");
gdm_xdmcp_send_decline (manager,
clnt_sa,
"Maximum number of open sessions reached");
} else {
- g_debug ("Maximum number of open XDMCP sessions from host %s reached",
- host);
+ gdm_debug ("Maximum number of open XDMCP sessions from host %s reached",
+ host);
gdm_xdmcp_send_decline (manager,
clnt_sa,
"Maximum number of open sessions from your host reached");
@@ -2087,7 +2088,7 @@ gdm_xdmcp_send_failed (GdmXdmcpManager *manager,
XdmcpHeader header;
ARRAY8 status;
- g_debug ("XDMCP: Sending FAILED to %ld", (long)sessid);
+ gdm_debug ("XDMCP: Sending FAILED to %ld", (long)sessid);
/*
* Don't translate, this goes over the wire to servers where we
@@ -2118,8 +2119,8 @@ gdm_xdmcp_send_refuse (GdmXdmcpManager *manager,
XdmcpHeader header;
GdmForwardQuery *fq;
- g_debug ("XDMCP: Sending REFUSE to %ld",
- (long)sessid);
+ gdm_debug ("XDMCP: Sending REFUSE to %ld",
+ (long)sessid);
header.version = XDM_PROTOCOL_VERSION;
header.opcode = (CARD16) REFUSE;
@@ -2158,11 +2159,11 @@ gdm_xdmcp_handle_manage (GdmXdmcpManager *manager,
char *host;
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("gdm_xdmcp_handle_manage: Got MANAGE from %s", host);
+ gdm_debug ("gdm_xdmcp_handle_manage: Got MANAGE from %s", host);
/* Check with tcp_wrappers if client is allowed to access */
if (! gdm_xdmcp_host_allow (clnt_sa)) {
- g_warning ("%s: Got Manage from banned host %s",
+ gdm_debug ("%s: Got Manage from banned host %s",
"gdm_xdmcp_handle_manage",
host);
g_free (host);
@@ -2172,30 +2173,29 @@ gdm_xdmcp_handle_manage (GdmXdmcpManager *manager,
/* SessionID */
if G_UNLIKELY (! XdmcpReadCARD32 (&manager->priv->buf, &clnt_sessid)) {
- g_warning ("%s: Could not read Session ID",
+ gdm_debug ("%s: Could not read Session ID",
"gdm_xdmcp_handle_manage");
return;
}
/* Remote display number */
if G_UNLIKELY (! XdmcpReadCARD16 (&manager->priv->buf, &clnt_dspnum)) {
- g_warning ("%s: Could not read Display Number",
+ gdm_debug ("%s: Could not read Display Number",
"gdm_xdmcp_handle_manage");
return;
}
/* Display Class */
if G_UNLIKELY (! XdmcpReadARRAY8 (&manager->priv->buf, &clnt_dspclass)) {
- g_warning ("%s: Could not read Display Class",
+ gdm_debug ("%s: Could not read Display Class",
"gdm_xdmcp_handle_manage");
return;
}
if G_UNLIKELY (gdm_daemon_config_get_value_bool (GDM_KEY_DEBUG)) {
char *s = g_strndup ((char *) clnt_dspclass.data, clnt_dspclass.length);
- g_debug ("gdm_xdmcp-handle_manage: Got display=%d, SessionID=%ld Class=%s from %s",
+ gdm_debug ("gdm_xdmcp-handle_manage: Got display=%d, SessionID=%ld Class=%s from %s",
(int)clnt_dspnum, (long)clnt_sessid, ve_sure_string (s), host);
-
g_free (s);
}
@@ -2203,7 +2203,7 @@ gdm_xdmcp_handle_manage (GdmXdmcpManager *manager,
if (d != NULL &&
d->dispstat == XDMCP_PENDING) {
- g_debug ("gdm_xdmcp_handle_manage: Looked up %s", d->name);
+ gdm_debug ("gdm_xdmcp_handle_manage: Looked up %s", d->name);
if (manager->priv->honor_indirect) {
id = gdm_choose_indirect_lookup (clnt_sa);
@@ -2245,10 +2245,10 @@ gdm_xdmcp_handle_manage (GdmXdmcpManager *manager,
return;
}
} else if G_UNLIKELY (d != NULL && d->dispstat == XDMCP_MANAGED) {
- g_debug ("gdm_xdmcp_handle_manage: Session id %ld already managed",
+ gdm_debug ("gdm_xdmcp_handle_manage: Session id %ld already managed",
(long)clnt_sessid);
} else {
- g_warning ("gdm_xdmcp_handle_manage: Failed to look up session id %ld",
+ gdm_debug ("gdm_xdmcp_handle_manage: Failed to look up session id %ld",
(long)clnt_sessid);
gdm_xdmcp_send_refuse (manager, clnt_sa, clnt_sessid);
}
@@ -2267,12 +2267,12 @@ gdm_xdmcp_handle_managed_forward (GdmXdmcpManager *manager,
struct sockaddr_storage *disp_sa;
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("gdm_xdmcp_handle_managed_forward: Got MANAGED_FORWARD from %s",
+ gdm_debug ("gdm_xdmcp_handle_managed_forward: Got MANAGED_FORWARD from %s",
host);
/* Check with tcp_wrappers if client is allowed to access */
if (! gdm_xdmcp_host_allow (clnt_sa)) {
- g_warning ("%s: Got MANAGED_FORWARD from banned host %s",
+ gdm_debug ("%s: Got MANAGED_FORWARD from banned host %s",
"gdm_xdmcp_handle_request", host);
g_free (host);
return;
@@ -2281,14 +2281,14 @@ gdm_xdmcp_handle_managed_forward (GdmXdmcpManager *manager,
/* Hostname */
if G_UNLIKELY ( ! XdmcpReadARRAY8 (&manager->priv->buf, &clnt_address)) {
- g_warning ("%s: Could not read address",
+ gdm_debug ("%s: Could not read address",
"gdm_xdmcp_handle_managed_forward");
return;
}
disp_sa = NULL;
if (! create_sa_from_request (&clnt_address, NULL, clnt_sa->ss_family, &disp_sa)) {
- g_warning ("Unable to parse address for request");
+ gdm_debug ("Unable to parse address for request");
XdmcpDisposeARRAY8 (&clnt_address);
return;
}
@@ -2315,11 +2315,11 @@ gdm_xdmcp_handle_got_managed_forward (GdmXdmcpManager *manager,
char *host;
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("gdm_xdmcp_handle_got_managed_forward: Got MANAGED_FORWARD from %s",
+ gdm_debug ("gdm_xdmcp_handle_got_managed_forward: Got MANAGED_FORWARD from %s",
host);
if (! gdm_xdmcp_host_allow (clnt_sa)) {
- g_warning ("%s: Got GOT_MANAGED_FORWARD from banned host %s",
+ gdm_debug ("%s: Got GOT_MANAGED_FORWARD from banned host %s",
"gdm_xdmcp_handle_request", host);
g_free (host);
return;
@@ -2328,13 +2328,13 @@ gdm_xdmcp_handle_got_managed_forward (GdmXdmcpManager *manager,
/* Hostname */
if G_UNLIKELY ( ! XdmcpReadARRAY8 (&manager->priv->buf, &clnt_address)) {
- g_warning ("%s: Could not read address",
+ gdm_debug ("%s: Could not read address",
"gdm_xdmcp_handle_got_managed_forward");
return;
}
if (! create_sa_from_request (&clnt_address, NULL, clnt_sa->ss_family, &disp_sa)) {
- g_warning ("%s: Could not read address",
+ gdm_debug ("%s: Could not read address",
"gdm_xdmcp_handle_got_managed_forward");
XdmcpDisposeARRAY8 (&clnt_address);
return;
@@ -2368,10 +2368,10 @@ gdm_xdmcp_send_alive (GdmXdmcpManager *manager,
}
}
- g_debug ("XDMCP: Sending ALIVE to %ld (running %d, sessid %ld)",
- (long)sessid,
- send_running,
- (long)send_sessid);
+ gdm_debug ("XDMCP: Sending ALIVE to %ld (running %d, sessid %ld)",
+ (long)sessid,
+ send_running,
+ (long)send_sessid);
header.version = XDM_PROTOCOL_VERSION;
header.opcode = (CARD16) ALIVE;
@@ -2397,11 +2397,11 @@ gdm_xdmcp_handle_keepalive (GdmXdmcpManager *manager,
char *host;
gdm_address_get_info (clnt_sa, &host, NULL);
- g_debug ("XDMCP: Got KEEPALIVE from %s", host);
+ gdm_debug ("XDMCP: Got KEEPALIVE from %s", host);
/* Check with tcp_wrappers if client is allowed to access */
if (! gdm_xdmcp_host_allow (clnt_sa)) {
- g_warning ("%s: Got KEEPALIVE from banned host %s",
+ gdm_debug ("%s: Got KEEPALIVE from banned host %s",
"gdm_xdmcp_handle_keepalive",
host);
g_free (host);
@@ -2411,14 +2411,14 @@ gdm_xdmcp_handle_keepalive (GdmXdmcpManager *manager,
/* Remote display number */
if G_UNLIKELY (! XdmcpReadCARD16 (&manager->priv->buf, &clnt_dspnum)) {
- g_warning ("%s: Could not read Display Number",
+ gdm_debug ("%s: Could not read Display Number",
"gdm_xdmcp_handle_keepalive");
return;
}
/* SessionID */
if G_UNLIKELY (! XdmcpReadCARD32 (&manager->priv->buf, &clnt_sessid)) {
- g_warning ("%s: Could not read Session ID",
+ gdm_debug ("%s: Could not read Session ID",
"gdm_xdmcp_handle_keepalive");
return;
}
@@ -2476,7 +2476,7 @@ decode_packet (GIOChannel *source,
sa_len = sizeof (clnt_sa);
- g_debug ("decode_packet: GIOCondition %d", (int)cond);
+ gdm_debug ("decode_packet: GIOCondition %d", (int)cond);
if ( ! (cond & G_IO_IN)) {
return TRUE;
@@ -2484,25 +2484,25 @@ decode_packet (GIOChannel *source,
res = XdmcpFill (manager->priv->socket_fd, &manager->priv->buf, (XdmcpNetaddr)&clnt_sa, &sa_len);
if G_UNLIKELY (! res) {
- g_debug (_("XDMCP: Could not create XDMCP buffer!"));
+ gdm_debug (_("XDMCP: Could not create XDMCP buffer!"));
return TRUE;
}
res = XdmcpReadHeader (&manager->priv->buf, &header);
if G_UNLIKELY (! res) {
- g_warning ("XDMCP: Could not read XDMCP header!");
+ gdm_debug ("XDMCP: Could not read XDMCP header!");
return TRUE;
}
if G_UNLIKELY (header.version != XDM_PROTOCOL_VERSION &&
header.version != GDM_XDMCP_PROTOCOL_VERSION) {
- g_warning ("XDMCP: Incorrect XDMCP version!");
+ gdm_debug ("XDMCP: Incorrect XDMCP version!");
return TRUE;
}
gdm_address_get_info (&clnt_sa, &host, &port);
- g_debug ("XDMCP: Received opcode %s from client %s : %s",
+ gdm_debug ("XDMCP: Received opcode %s from client %s : %s",
opcode_string (header.opcode),
host,
port);
@@ -2545,9 +2545,9 @@ decode_packet (GIOChannel *source,
break;
default:
- g_debug ("XDMCP: Unknown opcode from client %s : %s",
- host,
- port);
+ gdm_debug ("XDMCP: Unknown opcode from client %s : %s",
+ host,
+ port);
break;
}
@@ -2573,7 +2573,7 @@ gdm_xdmcp_manager_start (GdmXdmcpManager *manager,
return ret;
}
- g_debug ("XDMCP: Starting to listen on XDMCP port");
+ gdm_debug ("XDMCP: Starting to listen on XDMCP port");
ioc = g_io_channel_unix_new (manager->priv->socket_fd);
@@ -2863,7 +2863,7 @@ gdm_xdmcp_manager_init (GdmXdmcpManager *manager)
/* Fetch and store local hostname in XDMCP friendly format */
hostbuf[1023] = '\0';
if G_UNLIKELY (gethostname (hostbuf, 1023) != 0) {
- g_warning ("Could not get server hostname: %s!", g_strerror (errno));
+ gdm_debug ("Could not get server hostname: %s!", g_strerror (errno));
strcpy (hostbuf, "localhost.localdomain");
}
@@ -2888,8 +2888,7 @@ gdm_xdmcp_manager_init (GdmXdmcpManager *manager)
manager->priv->max_displays = gdm_daemon_config_get_value_int (GDM_KEY_MAX_SESSIONS);
manager->priv->max_pending_displays = gdm_daemon_config_get_value_int (GDM_KEY_MAX_PENDING);
manager->priv->max_wait = gdm_daemon_config_get_value_int (GDM_KEY_MAX_WAIT);
- manager->priv->willing_script = g_strdup(gdm_daemon_config_get_value_int (GDM_KEY_WILLING));
-
+ manager->priv->willing_script = g_strdup (gdm_daemon_config_get_value_string (GDM_KEY_WILLING));
}
static void
diff --git a/daemon/gdmconsolekit.c b/daemon/gdmconsolekit.c
index ce366ae7..4c9e167e 100644
--- a/daemon/gdmconsolekit.c
+++ b/daemon/gdmconsolekit.c
@@ -271,7 +271,7 @@ get_path_array_from_iter (DBusMessageIter *iter,
return buffer;
oom:
- g_warning ("%s %d : error allocating memory\n", __FILE__, __LINE__);
+ gdm_debug ("%s %d : error allocating memory\n", __FILE__, __LINE__);
return NULL;
}
diff --git a/daemon/misc.c b/daemon/misc.c
index c8d950d6..31afc8ea 100644
--- a/daemon/misc.c
+++ b/daemon/misc.c
@@ -634,7 +634,7 @@ gdm_exec_wait (char * const *argv,
g_access (argv[0], X_OK) != 0)
return -1;
- g_debug ("Forking extra process: %s", argv[0]);
+ gdm_debug ("Forking extra process: %s", argv[0]);
pid = gdm_fork_extra ();
if (pid == 0) {
diff --git a/daemon/server.c b/daemon/server.c
index 5a186c98..b3bc360d 100644
--- a/daemon/server.c
+++ b/daemon/server.c
@@ -145,7 +145,7 @@ gdm_exec_fbconsole (GdmDisplay *disp)
argv[2] = disp->name;
argv[3] = NULL;
- g_debug ("Forking fbconsole");
+ gdm_debug ("Forking fbconsole");
pid = fork ();
if (pid == 0) {
@@ -1210,7 +1210,7 @@ gdm_server_spawn (GdmDisplay *d, const char *vtarg)
/* Fork into two processes. Parent remains the gdm process. Child
* becomes the X server. */
- g_debug ("Forking X server process");
+ gdm_debug ("Forking X server process");
gdm_sigterm_block_push ();
pid = d->servpid = fork ();
diff --git a/daemon/slave.c b/daemon/slave.c
index 7d2d0135..477d6313 100644
--- a/daemon/slave.c
+++ b/daemon/slave.c
@@ -1707,7 +1707,7 @@ focus_first_x_window (const char *class_res_name)
p[1] = -1;
}
- g_debug ("Forking process to focus first X11 window");
+ gdm_debug ("Forking process to focus first X11 window");
pid = fork ();
if G_UNLIKELY (pid < 0) {
@@ -1850,7 +1850,7 @@ run_config (GdmDisplay *display, struct passwd *pwent)
XSync (d->dsp, False);
}
- g_debug ("Forking GDM configuration process");
+ gdm_debug ("Forking GDM configuration process");
gdm_sigchld_block_push ();
gdm_sigterm_block_push ();
@@ -2042,7 +2042,7 @@ play_login_sound (const char *sound_file)
gdm_sigchld_block_push ();
gdm_sigterm_block_push ();
- g_debug ("Forking sound program: %s", soundprogram);
+ gdm_debug ("Forking sound program: %s", soundprogram);
pid = fork ();
if (pid == 0)
@@ -2635,7 +2635,7 @@ gdm_slave_greeter (void)
system ("/usr/bin/setfacl -m user:gdm:rwx,mask:rwx /dev/audio");
system ("/usr/bin/setfacl -m user:gdm:rwx,mask:rwx /dev/audioctl");
#endif
- g_debug ("Forking greeter process: %s", command);
+ gdm_debug ("Forking greeter process: %s", command);
/* Fork. Parent is gdmslave, child is greeter process. */
gdm_sigchld_block_push ();
@@ -3122,7 +3122,7 @@ gdm_slave_chooser (void)
gdm_slave_exec_script (d, gdm_daemon_config_get_value_string (GDM_KEY_DISPLAY_INIT_DIR),
NULL, NULL, FALSE /* pass_stdout */);
- g_debug ("Forking chooser process: %s", gdm_daemon_config_get_value_string (GDM_KEY_CHOOSER));
+ gdm_debug ("Forking chooser process: %s", gdm_daemon_config_get_value_string (GDM_KEY_CHOOSER));
/* Fork. Parent is gdmslave, child is greeter process. */
gdm_sigchld_block_push ();
@@ -4779,7 +4779,7 @@ gdm_slave_session_start (void)
ck_session_cookie = open_ck_session (pwent, d, session);
#endif
- g_debug ("Forking user session");
+ gdm_debug ("Forking user session");
/* Start user process */
gdm_sigchld_block_push ();
@@ -5832,7 +5832,7 @@ gdm_slave_exec_script (GdmDisplay *d,
create_temp_auth_file ();
- g_debug ("Forking extra process: %s", script);
+ gdm_debug ("Forking extra process: %s", script);
extra_process = pid = gdm_fork_extra ();
@@ -5999,7 +5999,7 @@ gdm_slave_parse_enriched_login (GdmDisplay *d, const gchar *s)
gdm_error (_("%s: Failed creating pipe"),
"gdm_slave_parse_enriched_login");
} else {
- g_debug ("Forking extra process: %s", str->str);
+ gdm_debug ("Forking extra process: %s", str->str);
extra_process = pid = gdm_fork_extra ();
diff --git a/daemon/verify-crypt.c b/daemon/verify-crypt.c
index b002685b..526033f1 100644
--- a/daemon/verify-crypt.c
+++ b/daemon/verify-crypt.c
@@ -178,7 +178,7 @@ gdm_verify_user (GdmDisplay *d,
if (pwent == NULL) {
gdm_sleep_no_signal (gdm_daemon_config_get_value_int (GDM_KEY_RETRY_DELAY));
- g_warning ("Couldn't authenticate user");
+ gdm_debug ("Couldn't authenticate user");
print_cant_auth_errbox ();
@@ -192,7 +192,7 @@ gdm_verify_user (GdmDisplay *d,
if (ppasswd == NULL || (ppasswd[0] != '\0' &&
strcmp (crypt (passwd, ppasswd), ppasswd) != 0)) {
gdm_sleep_no_signal (gdm_daemon_config_get_value_int (GDM_KEY_RETRY_DELAY));
- g_warning ("Couldn't authenticate user");
+ gdm_debug ("Couldn't authenticate user");
print_cant_auth_errbox ();
@@ -206,7 +206,7 @@ gdm_verify_user (GdmDisplay *d,
( ! gdm_daemon_config_get_value_bool (GDM_KEY_ALLOW_REMOTE_ROOT) &&
! d->attached)) && pwent->pw_uid == 0) {
- g_warning ("Root login disallowed on display '%s'", d->name);
+ gdm_debug ("Root login disallowed on display '%s'", d->name);
gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
_("The system administrator "
"is not allowed to login "
@@ -224,7 +224,7 @@ gdm_verify_user (GdmDisplay *d,
/* Check with the 'loginrestrictions' function
if the user has been disallowed */
if (loginrestrictions (login, 0, NULL, &message) != 0) {
- g_warning ("User not allowed to log in");
+ gdm_debug ("User not allowed to log in");
gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
_("\nThe system administrator "
"has disabled your "
@@ -248,7 +248,7 @@ gdm_verify_user (GdmDisplay *d,
(strcmp (pwent->pw_shell, NOLOGIN) == 0 ||
strcmp (pwent->pw_shell, "/bin/true") == 0 ||
strcmp (pwent->pw_shell, "/bin/false") == 0)) {
- g_warning ("User not allowed to log in");
+ gdm_debug ("User not allowed to log in");
gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
_("\nThe system administrator "
"has disabled your "
@@ -273,7 +273,7 @@ gdm_verify_user (GdmDisplay *d,
}
if ( ! gdm_setup_gids (login, pwent->pw_gid)) {
- g_warning ("Cannot set user group");
+ gdm_debug ("Cannot set user group");
gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
_("\nCannot set your user group; "
"you will not be able to log in. "
@@ -286,7 +286,7 @@ gdm_verify_user (GdmDisplay *d,
switch (passwdexpired (login, &info_msg)) {
case 1 :
- g_warning ("User password has expired");
+ gdm_debug ("User password has expired");
gdm_errorgui_error_box (d, GTK_MESSAGE_ERROR,
_("You are required to change your password.\n"
"Please choose a new one."));
@@ -359,7 +359,7 @@ gdm_verify_user (GdmDisplay *d,
break;
case 2 :
- g_warning ("User password has expired");
+ gdm_debug ("User password has expired");
gdm_errorgui_error_box (d, GTK_MESSAGE_ERROR,
_("Your password has expired.\n"
"Only a system administrator can now change it"));
@@ -368,7 +368,7 @@ gdm_verify_user (GdmDisplay *d,
break;
case -1 :
- g_warning ("Internal error on passwdexpired");
+ gdm_debug ("Internal error on passwdexpired");
gdm_errorgui_error_box (d, GTK_MESSAGE_ERROR,
_("An internal error occurred. You will not be able to log in.\n"
"Please try again later or contact your system administrator."));
@@ -405,12 +405,12 @@ gdm_verify_setup_user (GdmDisplay *d,
pwent = getpwnam (login);
if (pwent == NULL) {
- g_warning ("Cannot get passwd structure");
+ gdm_debug ("Cannot get passwd structure");
return FALSE;
}
if ( ! gdm_setup_gids (login, pwent->pw_gid)) {
- g_warning ("Cannot set user group");
+ gdm_debug ("Cannot set user group");
gdm_errorgui_error_box (d,
GTK_MESSAGE_ERROR,
_("\nCannot set your user group; "
diff --git a/daemon/verify-shadow.c b/daemon/verify-shadow.c
index d23d13d4..69d5db40 100644
--- a/daemon/verify-shadow.c
+++ b/daemon/verify-shadow.c
@@ -199,7 +199,7 @@ gdm_verify_user (GdmDisplay *d,
if (pwent == NULL) {
gdm_sleep_no_signal (gdm_daemon_config_get_value_int (GDM_KEY_RETRY_DELAY));
- g_warning ("Couldn't authenticate user");
+ gdm_debug ("Couldn't authenticate user");
print_cant_auth_errbox ();
@@ -213,7 +213,7 @@ gdm_verify_user (GdmDisplay *d,
if (ppasswd == NULL || (ppasswd[0] != '\0' &&
strcmp (crypt (passwd, ppasswd), ppasswd) != 0)) {
gdm_sleep_no_signal (gdm_daemon_config_get_value_int (GDM_KEY_RETRY_DELAY));
- g_warning ("Couldn't authenticate user");
+ gdm_debug ("Couldn't authenticate user");
print_cant_auth_errbox ();
@@ -227,7 +227,7 @@ gdm_verify_user (GdmDisplay *d,
( ! gdm_daemon_config_get_value_bool (GDM_KEY_ALLOW_REMOTE_ROOT) &&
! d->attached)) && pwent->pw_uid == 0) {
- g_warning ("Root login disallowed on display '%s'", d->name);
+ gdm_debug ("Root login disallowed on display '%s'", d->name);
gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
_("The system administrator "
"is not allowed to login "
@@ -245,7 +245,7 @@ gdm_verify_user (GdmDisplay *d,
/* Check with the 'loginrestrictions' function
if the user has been disallowed */
if (loginrestrictions (login, 0, NULL, &message) != 0) {
- g_warning ("User not allowed to log in");
+ gdm_debug ("User not allowed to log in");
gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
_("\nThe system administrator "
"has disabled your "
@@ -269,7 +269,7 @@ gdm_verify_user (GdmDisplay *d,
(strcmp (pwent->pw_shell, NOLOGIN) == 0 ||
strcmp (pwent->pw_shell, "/bin/true") == 0 ||
strcmp (pwent->pw_shell, "/bin/false") == 0)) {
- g_warning ("User not allowed to log in");
+ gdm_debug ("User not allowed to log in");
gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
_("\nThe system administrator "
"has disabled your "
@@ -294,7 +294,7 @@ gdm_verify_user (GdmDisplay *d,
}
if ( ! gdm_setup_gids (login, pwent->pw_gid)) {
- g_warning ("Cannot set user group");
+ gdm_debug ("Cannot set user group");
gdm_slave_greeter_ctl_no_ret (GDM_ERRBOX,
_("\nCannot set your user group; "
"you will not be able to log in. "
@@ -307,7 +307,7 @@ gdm_verify_user (GdmDisplay *d,
switch (passwdexpired (login, &info_msg)) {
case 1 :
- g_warning ("User password has expired");
+ gdm_debug ("User password has expired");
gdm_errorgui_error_box (d, GTK_MESSAGE_ERROR,
_("You are required to change your password.\n"
"Please choose a new one."));
@@ -381,7 +381,7 @@ gdm_verify_user (GdmDisplay *d,
break;
case 2 :
- g_warning ("User password has expired");
+ gdm_debug ("User password has expired");
gdm_errorgui_error_box (d, GTK_MESSAGE_ERROR,
_("Your password has expired.\n"
"Only a system administrator can now change it"));
@@ -390,7 +390,7 @@ gdm_verify_user (GdmDisplay *d,
break;
case -1 :
- g_warning ("Internal error on passwdexpired");
+ gdm_debug ("Internal error on passwdexpired");
gdm_errorgui_error_box (d, GTK_MESSAGE_ERROR,
_("An internal error occurred. You will not be able to log in.\n"
"Please try again later or contact your system administrator."));
@@ -427,12 +427,12 @@ gdm_verify_setup_user (GdmDisplay *d,
pwent = getpwnam (login);
if (pwent == NULL) {
- g_warning ("Cannot get passwd structure for user");
+ gdm_debug ("Cannot get passwd structure for user");
return FALSE;
}
if ( ! gdm_setup_gids (login, pwent->pw_gid)) {
- g_warning ("Cannot set user group");
+ gdm_debug ("Cannot set user group");
gdm_errorgui_error_box (d,
GTK_MESSAGE_ERROR,
_("\nCannot set your user group; "
diff --git a/daemon/gdm.c b/daemon/gdm.c
index 43340309..03d5d7a8 100644
--- a/daemon/gdm.c
+++ b/daemon/gdm.c
@@ -249,7 +249,7 @@ gdm_start_first_unborn_local (int delay)
d->type == TYPE_STATIC &&
d->dispstat == DISPLAY_UNBORN) {
GdmXserver *svr;
- g_debug ("gdm_start_first_unborn_local: "
+ gdm_debug ("gdm_start_first_unborn_local: "
"Starting %s", d->name);
/* well sleep at least 'delay' seconds
@@ -296,7 +296,7 @@ gdm_final_cleanup (void)
displays = gdm_daemon_config_get_display_list ();
- g_debug ("gdm_final_cleanup");
+ gdm_debug ("gdm_final_cleanup");
if (extra_process > 1) {
/* we sigterm extra processes, and we
@@ -600,12 +600,12 @@ try_command (const char *command)
gboolean res;
int status;
- g_debug ("Running %s", command);
+ gdm_debug ("Running %s", command);
error = NULL;
res = g_spawn_command_line_sync (command, NULL, NULL, &status, &error);
if (error != NULL) {
- g_warning ("Command failed %s: %s", command, error->message);
+ gdm_debug ("Command failed %s: %s", command, error->message);
g_error_free (error);
}
else {
@@ -694,7 +694,7 @@ halt_machine (void)
{
const char **s;
- g_debug (_("Master halting..."));
+ gdm_debug (_("Master halting..."));
s = gdm_daemon_config_get_value_string_array (GDM_KEY_HALT);
@@ -716,7 +716,7 @@ restart_machine (void)
{
const char **s;
- g_debug (_("Restarting computer..."));
+ gdm_debug (_("Restarting computer..."));
s = gdm_daemon_config_get_value_string_array (GDM_KEY_REBOOT);
@@ -759,7 +759,7 @@ custom_cmd_restart (long cmd_id)
char **argv;
const char *s;
- g_debug (_("Executing custom command %ld with restart option..."), cmd_id);
+ gdm_debug (_("Executing custom command %ld with restart option..."), cmd_id);
gdm_final_cleanup ();
VE_IGNORE_EINTR (g_chdir ("/"));
@@ -791,7 +791,7 @@ custom_cmd_no_restart (long cmd_id)
{
pid_t pid;
- g_debug (_("Executing custom command %ld with no restart option ..."), cmd_id);
+ gdm_debug (_("Executing custom command %ld with no restart option ..."), cmd_id);
pid = fork ();
@@ -831,7 +831,7 @@ custom_cmd_no_restart (long cmd_id)
if (p_stat > 0) {
if G_LIKELY (WIFEXITED (exitstatus)){
status = WEXITSTATUS (exitstatus);
- g_debug (_("custom_cmd: child %d returned %d"), p_stat, status);
+ gdm_debug (_("custom_cmd: child %d returned %d"), p_stat, status);
}
return;
}
@@ -856,7 +856,7 @@ gdm_cleanup_children (void)
if G_LIKELY (WIFEXITED (exitstatus)) {
status = WEXITSTATUS (exitstatus);
crashed = FALSE;
- g_debug ("gdm_cleanup_children: child %d returned %d", pid, status);
+ gdm_debug ("gdm_cleanup_children: child %d returned %d", pid, status);
} else {
status = EXIT_SUCCESS;
crashed = TRUE;
@@ -864,7 +864,7 @@ gdm_cleanup_children (void)
if (WTERMSIG (exitstatus) == SIGTERM ||
WTERMSIG (exitstatus) == SIGINT) {
/* we send these signals, sometimes children don't handle them */
- g_debug ("gdm_cleanup_children: child %d died of signal %d (TERM/INT)", pid,
+ gdm_debug ("gdm_cleanup_children: child %d died of signal %d (TERM/INT)", pid,
(int)WTERMSIG (exitstatus));
} else {
gdm_error ("gdm_cleanup_children: child %d crashed of signal %d", pid,
@@ -1055,7 +1055,7 @@ gdm_cleanup_children (void)
break;
case DISPLAY_XFAILED: /* X sucks */
- g_debug ("X failed!");
+ gdm_debug ("X failed!");
/* inform about error if needed */
if (d->socket_conn != NULL) {
GdmConnection *conn = d->socket_conn;
@@ -1080,9 +1080,9 @@ gdm_cleanup_children (void)
/* well sleep at least 3 seconds before starting */
d->sleep_before_run = 3;
} else if (d->x_faileds >= 3) {
- g_debug ("gdm_child_action: dealing with X crashes");
+ gdm_debug ("gdm_child_action: dealing with X crashes");
if ( ! deal_with_x_crashes (d)) {
- g_debug ("gdm_child_action: Aborting display");
+ gdm_debug ("gdm_child_action: Aborting display");
/* an original way to deal with these things:
* "Screw you guys, I'm going home!" */
gdm_display_unmanage (d);
@@ -1092,7 +1092,7 @@ gdm_cleanup_children (void)
gdm_start_first_unborn_local (3 /* delay */);
break;
}
- g_debug ("gdm_child_action: Trying again");
+ gdm_debug ("gdm_child_action: Trying again");
/* reset */
d->x_faileds = 0;
@@ -1109,7 +1109,7 @@ gdm_cleanup_children (void)
case DISPLAY_REMANAGE: /* Remanage display */
default:
- g_debug ("gdm_child_action: In remanage");
+ gdm_debug ("gdm_child_action: In remanage");
/* if we did REMANAGE, that means that we're no longer failing */
if (status == DISPLAY_REMANAGE) {
@@ -1266,7 +1266,7 @@ mainloop_sig_callback (int sig, gpointer data)
/* signals are at somewhat random times aren't they? */
gdm_random_tick ();
- g_debug ("mainloop_sig_callback: Got signal %d", (int)sig);
+ gdm_debug ("mainloop_sig_callback: Got signal %d", (int)sig);
switch (sig)
{
case SIGCHLD:
@@ -1276,7 +1276,7 @@ mainloop_sig_callback (int sig, gpointer data)
case SIGINT:
case SIGTERM:
- g_debug ("mainloop_sig_callback: Got TERM/INT. Going down!");
+ gdm_debug ("mainloop_sig_callback: Got TERM/INT. Going down!");
gdm_final_cleanup ();
exit (EXIT_SUCCESS);
break;
@@ -1757,7 +1757,7 @@ main (int argc, char *argv[])
gdm_signal_ignore (SIGLOST);
#endif
- g_debug ("gdm_main: Here we go...");
+ gdm_debug ("gdm_main: Here we go...");
/* Init XDMCP if applicable */
if (gdm_daemon_config_get_value_bool (GDM_KEY_XDMCP) && ! gdm_wait_for_go) {
@@ -1778,7 +1778,7 @@ main (int argc, char *argv[])
/* Accept remote connections */
if (gdm_daemon_config_get_value_bool (GDM_KEY_XDMCP) && ! gdm_wait_for_go) {
- g_debug ("Accepting XDMCP connections...");
+ gdm_debug ("Accepting XDMCP connections...");
gdm_xdmcp_run ();
}
@@ -1789,7 +1789,7 @@ main (int argc, char *argv[])
while (1)
{
g_main_loop_run (main_loop);
- g_debug ("main: Exited main loop");
+ gdm_debug ("main: Exited main loop");
}
return EXIT_SUCCESS; /* Not reached */
@@ -1992,14 +1992,14 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
char *s = g_strndup
(msg, strlen (GDM_SOP_COOKIE " XXXX XX"));
/* cut off most of the cookie for "security" */
- g_debug ("Handling message: '%s...'", s);
+ gdm_debug ("Handling message: '%s...'", s);
g_free (s);
} else if (strncmp (msg, GDM_SOP_SYSLOG " ",
strlen (GDM_SOP_SYSLOG " ")) != 0) {
/* Don't print out the syslog message as it will
* be printed out anyway as that's the whole point
* of the message. */
- g_debug ("Handling message: '%s'", msg);
+ gdm_debug ("Handling message: '%s'", msg);
}
}
@@ -2028,7 +2028,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (d != NULL) {
g_free (d->chosen_hostname);
d->chosen_hostname = g_strdup (p);
- g_debug ("Got CHOSEN_LOCAL == %s", p);
+ gdm_debug ("Got CHOSEN_LOCAL == %s", p);
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2046,7 +2046,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (d != NULL) {
d->servpid = pid;
- g_debug ("Got XPID == %ld", (long)pid);
+ gdm_debug ("Got XPID == %ld", (long)pid);
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2064,7 +2064,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (d != NULL) {
d->sesspid = pid;
- g_debug ("Got SESSPID == %ld", (long)pid);
+ gdm_debug ("Got SESSPID == %ld", (long)pid);
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2082,7 +2082,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (d != NULL) {
d->greetpid = pid;
- g_debug ("Got GREETPID == %ld", (long)pid);
+ gdm_debug ("Got GREETPID == %ld", (long)pid);
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2100,7 +2100,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (d != NULL) {
d->chooserpid = pid;
- g_debug ("Got CHOOSERPID == %ld", (long)pid);
+ gdm_debug ("Got CHOOSERPID == %ld", (long)pid);
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2118,7 +2118,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (d != NULL) {
d->logged_in = logged_in ? TRUE : FALSE;
- g_debug ("Got logged in == %s",
+ gdm_debug ("Got logged in == %s",
d->logged_in ? "TRUE" : "FALSE");
/* whack connections about this display if a user
@@ -2154,7 +2154,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
g_free (d->name);
d->name = g_strdup_printf (":%d", disp_num);
d->dispnum = disp_num;
- g_debug ("Got DISP_NUM == %d", disp_num);
+ gdm_debug ("Got DISP_NUM == %d", disp_num);
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2173,7 +2173,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (d != NULL) {
d->vt = vt_num;
- g_debug ("Got VT_NUM == %d", vt_num);
+ gdm_debug ("Got VT_NUM == %d", vt_num);
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2200,7 +2200,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (d != NULL) {
g_free (d->login);
d->login = g_strdup (p);
- g_debug ("Got LOGIN == %s", p);
+ gdm_debug ("Got LOGIN == %s", p);
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2230,7 +2230,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
GSList *displays;
displays = gdm_daemon_config_get_display_list ();
- g_debug ("Got QUERYLOGIN %s", p);
+ gdm_debug ("Got QUERYLOGIN %s", p);
for (li = displays; li != NULL; li = li->next) {
GdmDisplay *di = li->data;
if (di->logged_in &&
@@ -2289,7 +2289,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (d == NULL)
return;
- g_debug ("Got MIGRATE %s", p);
+ gdm_debug ("Got MIGRATE %s", p);
for (li = displays; li != NULL; li = li->next) {
GdmDisplay *di = li->data;
if (di->logged_in && strcmp (di->name, p) == 0) {
@@ -2323,7 +2323,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (d != NULL) {
g_free (d->cookie);
d->cookie = g_strdup (p);
- g_debug ("Got COOKIE == <secret>");
+ gdm_debug ("Got COOKIE == <secret>");
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2350,7 +2350,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (d != NULL) {
g_free (d->authfile);
d->authfile = g_strdup (p);
- g_debug ("Got AUTHFILE == %s", d->authfile);
+ gdm_debug ("Got AUTHFILE == %s", d->authfile);
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2387,7 +2387,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
if (conn != NULL)
gdm_connection_write (conn, error);
- g_debug ("Got FLEXI_ERR == %d", err);
+ gdm_debug ("Got FLEXI_ERR == %d", err);
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2414,7 +2414,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
gdm_display_unmanage (d);
}
- g_debug ("Got FLEXI_OK");
+ gdm_debug ("Got FLEXI_OK");
/* send ack */
send_slave_ack (d, NULL);
}
@@ -2462,8 +2462,8 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
return;
p++;
- /* FIXME: use g_critical or g_debug when required */
- g_warning ("(child %ld) %s", pid, p);
+ /* FIXME: use g_critical or gdm_debug when required */
+ gdm_debug ("(child %ld) %s", pid, p);
} else if (strcmp (msg, GDM_SOP_START_NEXT_LOCAL) == 0) {
gdm_start_first_unborn_local (3 /* delay */);
} else if (strcmp (msg, GDM_SOP_HUP_ALL_GREETERS) == 0) {
@@ -2493,7 +2493,7 @@ gdm_handle_message (GdmConnection *conn, const char *msg, gpointer data)
/* Init XDMCP if applicable */
if (old_wait && gdm_daemon_config_get_value_bool (GDM_KEY_XDMCP)) {
if (gdm_xdmcp_init ()) {
- g_debug ("Accepting XDMCP connections...");
+ gdm_debug ("Accepting XDMCP connections...");
gdm_xdmcp_run ();
}
}
@@ -3021,7 +3021,7 @@ handle_flexi_server (GdmConnection *conn,
gchar *bin;
uid_t server_uid = 0;
- g_debug ("flexi server: '%s'", server);
+ gdm_debug ("flexi server: '%s'", server);
if (gdm_wait_for_go) {
if (conn != NULL)
@@ -3470,7 +3470,7 @@ sup_handle_flexi_xserver (GdmConnection *conn,
has_user = strncmp (msg, GDM_SUP_FLEXI_XSERVER_USER " ", strlen (GDM_SUP_FLEXI_XSERVER_USER " ")) == 0;
- g_debug ("Handling flexi request has-user:%d", has_user);
+ gdm_debug ("Handling flexi request has-user:%d", has_user);
/* Only allow locally authenticated connections */
if ( ! GDM_CONN_AUTHENTICATED (conn)) {
@@ -3553,7 +3553,7 @@ sup_handle_flexi_xnest (GdmConnection *conn,
has_user = strncmp (msg, GDM_SUP_FLEXI_XNEST_USER " ", strlen (GDM_SUP_FLEXI_XNEST_USER " ")) == 0;
- g_debug ("Handling flexi xnest request has-user:%d", has_user);
+ gdm_debug ("Handling flexi xnest request has-user:%d", has_user);
if (has_user) {
rest = msg + strlen (GDM_SUP_FLEXI_XNEST_USER " ");
@@ -3575,7 +3575,7 @@ sup_handle_flexi_xnest (GdmConnection *conn,
* connection */
g_free (xauthfile);
gdm_connection_close (conn);
- g_warning ("Unable to get display name from request");
+ gdm_debug ("Unable to get display name from request");
return;
}
@@ -3652,8 +3652,8 @@ sup_handle_get_config (GdmConnection *conn,
* value at all.
*/
- g_debug ("Handling GET_CONFIG: %s for display %s", splitstr[0],
- splitstr[1] ? splitstr[1] : "(null)");
+ gdm_debug ("Handling GET_CONFIG: %s for display %s", splitstr[0],
+ splitstr[1] ? splitstr[1] : "(null)");
res = gdm_daemon_config_to_string (splitstr[0], splitstr[1], &retval);
@@ -4198,10 +4198,10 @@ gdm_handle_user_message (GdmConnection *conn,
gpointer data)
{
- g_debug ("Handling user message: '%s'", msg);
+ gdm_debug ("Handling user message: '%s'", msg);
if (gdm_connection_get_message_count (conn) > GDM_SUP_MAX_MESSAGES) {
- g_debug ("Closing connection, %d messages reached", GDM_SUP_MAX_MESSAGES);
+ gdm_debug ("Closing connection, %d messages reached", GDM_SUP_MAX_MESSAGES);
gdm_connection_write (conn, "ERROR 200 Too many messages\n");
gdm_connection_close (conn);
return;